#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmark
version:              0.0.7.3
visibility:           public
id:                   mmark-0.0.7.3-5lJNurGLvXm1e39RFyfdHt
key:                  mmark-0.0.7.3-5lJNurGLvXm1e39RFyfdHt
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  d6e66e050dd687e6bbb0288b174f37fc
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-8.10.5/site-local/mmark-0.0.7.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mmark-0.0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mmark-0.0.7.3
hs-libraries:         HSmmark-0.0.7.3-5lJNurGLvXm1e39RFyfdHt
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB containers-0.6.4.1
    deepseq-1.4.4.0 dlist-1.0-2pxhAw6JY91eMk6tw7lC2
    email-validate-2.3.2.13-4Do5pTS423H5nxE3J1H2aZ
    foldl-1.4.11-3n1BKNutTNL5yIx0tnC0E
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    html-entity-map-0.1.0.0-BGsOJK6C6uh40lP2reKqvq
    lucid-2.9.12.1-9oIuMQbP4r48YxtDtY8LUx
    megaparsec-9.0.1-CgNxKp13Re58VqY3iga6b3
    microlens-0.4.12.0-7mbtYeVEJj9DE2AV66WaoK
    microlens-th-0.4.3.10-L22hJd4Bpy6EfILCAvCrvo
    modern-uri-0.3.4.1-v472keFKueHixOvPxm7G0 mtl-2.2.2
    parser-combinators-1.3.0-I56cvBuZMEG2VbjtPZAqZY text-1.2.4.1
    text-metrics-0.3.0-KX5t5hBXlFc50u8T4lDfZp
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    yaml-0.11.5.0-7UJv2Fq2f113FoCoCodYb3

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

